Package: MetaEntropy
Title: Functional Shannon Entropy for Virome Mutational Analysis
Version: 1.4
Date: 2026-08-31
Authors@R: c( person("Leandro Roberto", "Jones", email = "lrj000@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-5877-4194")),
    person("Julieta Marina", "Manrique", role = c("aut"), comment = c(ORCID = "0000-0001-8712-6666")))
Description: Estimates Shannon entropy, per gene and per genomic position,
    associated with non-synonymous mutation frequencies in viral populations,
    such as wastewater samples. The package uses codon translations for
    functional insights. Each amino acid can be treated as an individual state,
    resulting in a 20-state entropy computation, or grouped into one of six
    physicochemical classes, adding further functional context. Provides
    normalized values (0-1 scale) to facilitate the direct comparison of
    different genomic positions or total functional entropy across multiple
    metagenomes. Designed to analyze mutational data using tabular 'Single
    Nucleotide Variant' (SNV) frequency tables generated by variant callers
    (e.g., 'iVar' or 'LoFreq'), operating independently of consensus sequence
    estimation and multiple sequence alignment.
Encoding: UTF-8
Depends: R (>= 4.1.0)
LazyData: true
Suggests: rmarkdown, tidyr
Imports: ggplot2, patchwork, beeswarm, ggbeeswarm, knitr, dplyr,
        grDevices, rlang
VignetteBuilder: knitr
License: MIT + file LICENSE
Config/roxygen2/version: 8.1.0
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-09-02 14:31:17 UTC; leandro
Author: Leandro Roberto Jones [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5877-4194>),
  Julieta Marina Manrique [aut] (ORCID:
    <https://orcid.org/0000-0001-8712-6666>)
Maintainer: Leandro Roberto Jones <lrj000@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-03 14:10:02 UTC
