# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,entropyProfile)
S3method(plot,entropyProfile)
S3method(print,profileSummary)
S3method(print,tidyMutations)
S3method(summary,entropyProfile)
export(assessHotSpot)
export(entropyProfile)
export(getEntropySignature)
export(showMutations)
importFrom(patchwork,wrap_plots)
